@@ -22,14 +22,13 @@
 #include <qwhatsthis.h>
 #include <qdragobject.h>
 #include <qcombobox.h>
+#include <qapp.h>
 
 // include files for KDE
 #include <ktoolbar.h>
 #include <kmimetype.h>
 #include <kdebug.h>
-
-// application specific includes
-#include "kxmleditor.h"
+#include <kiconloader.h>
 
 //-------------------------------------------------------------------
 //
@@ -217,8 +216,8 @@ int KXmlEditorComboAction::findItem( const QString & text )
 class KXmlEditorDraggableLabel : public QLabel
 {
 public:
-    KXmlEditorDraggableLabel(KXMLEditorApp * mw, const QString & text, QWidget * parent = 0, const char * name = 0 )
-        : QLabel(text, parent, name), m_mw(mw)
+    KXmlEditorDraggableLabel( QWidget * pDragSource, const QString & text, QWidget * parent = 0, const char * name = 0 )
+        : QLabel(text, parent, name), m_pDragSource(pDragSource)
     { validDrag = false; }
 
 protected:
@@ -227,17 +226,20 @@ protected:
         validDrag = true;
         startDragPos = ev->pos();
     	}
-    void mouseMoveEvent( QMouseEvent * ev )
-    	{	if((startDragPos - ev->pos()).manhattanLength() > QApplication::startDragDistance())
-        	{	validDrag = false;
+	void mouseMoveEvent( QMouseEvent * ev )
+	{
+		if((startDragPos - ev->pos()).manhattanLength() > QApplication::startDragDistance())
+		{	validDrag = false;
 
-            if( m_mw->currentView() )
-            	{ QDragObject *pDragObject = new QTextDrag(m_mw->path(), m_mw);
-                pDragObject->setPixmap(KMimeType::pixmapForURL("text/plain", 0, KIcon::Small));
-                (void) pDragObject->drag();
-            	}
-        	}
-    	}
+			if ( ! text().isEmpty() )
+			{
+				QDragObject *pDragObject = new QTextDrag( text(), m_pDragSource );
+				pDragObject->setPixmap(KMimeType::pixmapForURL("text/plain", 0, KIcon::Small));
+				(void) pDragObject->drag();
+			}
+
+		}
+	}
     void mouseReleaseEvent( QMouseEvent * )
     {
         validDrag = false;
@@ -245,7 +247,7 @@ protected:
 private:
     QPoint startDragPos;
     bool validDrag;
-    KXMLEditorApp * m_mw;
+    QWidget * m_pDragSource;
 };
 
 //-------------------------------------------------------------------
@@ -269,7 +271,7 @@ int KXmlEditorLabelAction::plug( QWidget *widget, int index )
 
     int id = KAction::getToolButtonID();
 
-    m_label = new KXmlEditorDraggableLabel( static_cast<KXMLEditorApp *>(tb->mainWindow()), text(), widget );
+    m_label = new KXmlEditorDraggableLabel( tb->mainWindow(), text(), widget );
     m_label->setAlignment( Qt::AlignLeft | Qt::AlignVCenter | Qt::ShowPrefix );
     m_label->adjustSize();
     tb->insertWidget( id, m_label->width(), m_label, index );
