@@ -32,7 +32,8 @@
 #include <kdebug.h>
 #include <kedittoolbar.h>
 #include <kkeydialog.h>
-
+#include <kstatusbar.h>
+#include <kpopupmenu.h>
 // application specific includes
 #include "kxmleditor.h"
 #include "kxmleditorview.h"
@@ -315,17 +316,22 @@ void KXMLEditorApp::openDocumentFile(const KURL& url, const QString &strPath)
 {
   slotStatusMsg(i18n("Opening file..."));
 
-  doc->openDocument(url, QString::null);
+  if (!doc->openDocument(url, QString::null) )
+		{ slotStatusMsg(i18n("Ready. Opening %1 failed.").arg(url.url()));
+		}
+  else
+		{ setCaption(url.fileName(), false);
+		
+			if(strPath.length() > 0)
+  			slotPathComboActivated(strPath);
 
-  if(strPath.length() > 0)
-  	slotPathComboActivated(strPath);
+			// KDE wizard generated code not contain this condition, this
+			// cause empty lines in recent menu.
+			if(!url.isEmpty())
+				m_Actions.fileOpenRecent->addURL(url);
 
-	// KDE wizard generated code not contain this condition, this
-	// cause empty lines in recent menu.
-	if(!url.isEmpty())
-		m_Actions.fileOpenRecent->addURL(url);
-
-	slotStatusMsg(i18n("Ready."));
+		slotStatusMsg(i18n("Ready."));
+	}
 }
 
 
@@ -542,6 +548,8 @@ void KXMLEditorApp::slotFileSave()
   	slotFileSaveAs();
 	else
 		doc->saveDocument(doc->URL());
+		
+	setCaption(doc->URL().fileName(), doc->isModified());
 
   m_Actions.fileSave->setEnabled(false);
 
@@ -560,7 +568,7 @@ void KXMLEditorApp::slotFileSaveAs()
   if(!url.isEmpty())
   	{ doc->saveDocument(url);
     	m_Actions.fileOpenRecent->addURL(url);
-    	setCaption(url.fileName(),doc->isModified());
+    	setCaption(url.fileName(), doc->isModified());
     	
     	m_Actions.fileSave->setEnabled(false);	
   	}
