@@ -157,7 +157,10 @@ bool KXMLEditorDoc::openDocument(const KURL& url,
 		
 	// download XML file	
   QString tmpfile;
-  KIO::NetAccess::download(url, tmpfile);
+  if ( ! KIO::NetAccess::download(url, tmpfile) )
+		{ // Loading failed. (Happens when user gave wrong filename in command line...)
+			return false;
+		}
 
   // obtain file extension -----------------------------------------
 	QString strExtension;
@@ -261,19 +264,34 @@ bool KXMLEditorDoc::openSAX2(QFile &file)
 }
 
 /** Open XML file using DOM parser */
-bool KXMLEditorDoc::openDOM(QFile &file)
+bool KXMLEditorDoc::openDOM(QFile &fileXML)
 {
 	QDomDocument doc("mydocument");
 	
-	if(!file.open(IO_ReadOnly))
+	if(!fileXML.open(IO_ReadOnly))
       return false;
 
-  if(!doc.setContent(&file))
-  	{ file.close();
+	//--- L.V. 28.10.2001
+	//--- Fix from roman@lmail.loniis.ru. Support for nonlatin1 symbols
+ 	QTextStream txtstrmLocal(&fileXML);
+	txtstrmLocal.setEncoding(QTextStream::Locale);
+	QString strFileContents = txtstrmLocal.read();
+	
+	//-- Set string with XML to QDomDocument ------------------------------------------
+	
+  QString strErrorMsg;
+  int iErrorLine, iErrorColumn;
+
+  if(!doc.setContent(strFileContents, true, &strErrorMsg, &iErrorLine, &iErrorColumn)) // before fix: &file
+  	{ KMessageBox::error(0,
+												 i18n("%1 in line %2, column %3").arg(strErrorMsg).arg(iErrorLine).arg(iErrorColumn),
+												 i18n("Parsing error !"));
+
+      fileXML.close();
       return false;
     }
 
-  file.close();
+  fileXML.close();
 
   // get view
 	KXMLEditorView *pView = pViewList->first();
@@ -486,6 +504,7 @@ bool KXMLEditorDoc::saveDocument(const KURL& url, const char */*szFormat*/ /*=0*
 			}
 	
   modified=false;
+  doc_url = url;
   return true;
 }
 
